/*
**                      Softwarepraktikum iMaze
**                              1993/94
**                Joerg Czeranski    Hans-Ulrich Kiel
**
** Datei: fehler.h
**
** Kommentar:
**  Definiert Prototypen fuer die Fehlerbehandlungsfunktionen
*/


static char sccsid_fehler[] = "@(#)fehler.h	1.5 22 Nov 1994";


/* Prototypen fuer globale Grafik-Funktionen */

#ifdef __STDC__

void uebler_fehler(char **meldung, char *knopf);
void milder_fehler(char **meldung, char *knopf);

#else

void uebler_fehler();
void milder_fehler();

#endif
